@@ -1,38 +1,9 @@
 /*
  * nsd-plugin.h -- interface to NSD for a plugin.
  *
- * Erik Rozendaal, <erik@nlnetlabs.nl>
+ * Copyright (c) 2001-2004, NLnet Labs. All rights reserved.
  *
- * Copyright (c) 2003-2004, NLnet Labs. All rights reserved.
- *
- * This software is an open source.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * Redistributions of source code must retain the above copyright notice,
- * this list of conditions and the following disclaimer.
- *
- * Redistributions in binary form must reproduce the above copyright notice,
- * this list of conditions and the following disclaimer in the documentation
- * and/or other materials provided with the distribution.
- *
- * Neither the name of the NLNET LABS nor the names of its contributors may
- * be used to endorse or promote products derived from this software without
- * specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
- * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
- * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE
- * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
- * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
- * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
- * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
- * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
+ * See LICENSE for the license.
  *
  */
 
@@ -50,8 +21,6 @@
 #include <sys/types.h>
 #include <sys/socket.h>
 
-#include "nsd.h"
-#include "namedb.h"
 #include "query.h"
 
 /*
@@ -118,7 +87,7 @@ struct nsd_plugin_callback_args
 	/*
 	 * Set this if the callback returns NSD_PLUGIN_ERROR.
 	 */
-	int                  result_code;
+	nsd_rc_type          result_code;
 };
 typedef struct nsd_plugin_callback_args nsd_plugin_callback_args_type;
 
@@ -155,11 +124,10 @@ struct nsd_plugin_interface
 	void *(*region_alloc)(region_type *region, size_t size);
 	void (*region_free_all)(region_type *region);
 
-	const dname_type *(*dname_parse)(region_type *region,
-					 const char *name,
-					 const dname_type *origin);
+	const dname_type *(*dname_parse)(region_type *region, const char *name);
 
-	const char *(*dname_to_string)(const dname_type *dname);
+	const char *(*dname_to_string)(const dname_type *dname,
+				       const dname_type *origin);
 };
 typedef struct nsd_plugin_interface nsd_plugin_interface_type;
 
