@@ -1,45 +1,19 @@
 /*
  * nsd.h -- nsd(8) definitions and prototypes
  *
- * Alexis Yushin, <alexis@nlnetlabs.nl>
- *
  * Copyright (c) 2001-2004, NLnet Labs. All rights reserved.
  *
- * This software is an open source.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * Redistributions of source code must retain the above copyright notice,
- * this list of conditions and the following disclaimer.
- *
- * Redistributions in binary form must reproduce the above copyright notice,
- * this list of conditions and the following disclaimer in the documentation
- * and/or other materials provided with the distribution.
- *
- * Neither the name of the NLNET LABS nor the names of its contributors may
- * be used to endorse or promote products derived from this software without
- * specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
- * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
- * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE
- * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
- * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
- * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
- * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
- * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
+ * See LICENSE for the license.
  *
  */
 
 #ifndef	_NSD_H_
 #define	_NSD_H_
 
-#include "region-allocator.h"
+#include <signal.h>
+
+#include "dns.h"
+#include "edns.h"
 
 #define	NSD_RUN	0
 #define	NSD_RELOAD 1
@@ -58,8 +32,6 @@
 #define DEFAULT_AI_FAMILY AF_INET
 #endif
 
-#define	OPT_LEN	11U	 /* Length of the NSD EDNS response record. */
-
 #ifdef BIND8_STATS
 
 /* Counter for statistics */
@@ -94,14 +66,10 @@ struct nsd_child
 	pid_t pid;
 };
 
-struct edns_data
-{
-	char ok[OPT_LEN];
-	char error[OPT_LEN];
-};
-
 /* NSD configuration and run-time variables */
-struct	nsd {
+typedef struct nsd nsd_type;
+struct	nsd
+{
 	/*
 	 * Global region that is not deallocated until NSD shuts down.
 	 */
@@ -109,11 +77,10 @@ struct	nsd {
 	
 	/* Run-time variables */
 	pid_t		pid;
-	int		mode;
+	volatile sig_atomic_t mode;
 	unsigned        server_kind;
 	struct namedb	*db;
 	int		debug;
-	size_t		tcp_max_msglen;
 
 	size_t            child_count;
 	struct nsd_child *children;
@@ -136,9 +103,9 @@ struct	nsd {
 	/* UDP specific configuration */
 	struct nsd_socket udp[MAX_INTERFACES];
 
-	struct edns_data  edns_ipv4;	
+	edns_data_type edns_ipv4;	
 #if defined(INET6)
-	struct edns_data  edns_ipv6;
+	edns_data_type edns_ipv6;
 #endif
 
 	int maximum_tcp_count;
