@@ -90,8 +90,9 @@ log_file(int priority, const char *message)
 		priority_text = priority_info->name;
 	}
 	
-	fprintf(current_log_file, "%s[%d]: %s: %s",
-		global_ident, (int) getpid(), priority_text, message);
+	/* Bug #104, add time_t timestamp */
+	fprintf(current_log_file, "[%d] %s[%d]: %s: %s",
+		time(NULL), global_ident, (int) getpid(), priority_text, message);
 	length = strlen(message);
 	if (length == 0 || message[length - 1] != '\n') {
 		fprintf(current_log_file, "\n");
@@ -428,3 +429,50 @@ hexdigit_to_int(char ch)
 		abort();
 	}
 }
+
+/* Number of days per month (except for February in leap years). */
+static const int mdays[] = {
+    31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31
+};
+
+static int
+is_leap_year(int year)
+{
+    return year % 4 == 0 && (year % 100 != 0 || year % 400 == 0);
+}
+
+static int
+leap_days(int y1, int y2)
+{
+    --y1;
+    --y2;
+    return (y2/4 - y1/4) - (y2/100 - y1/100) + (y2/400 - y1/400);
+}
+
+/*
+ * Code adapted from Python 2.4.1 sources (Lib/calendar.py).
+ */
+time_t
+mktime_from_utc(const struct tm *tm)
+{
+    int year = 1900 + tm->tm_year;
+    time_t days = 365 * (year - 1970) + leap_days(1970, year);
+    time_t hours;
+    time_t minutes;
+    time_t seconds;
+    int i;
+
+    for (i = 0; i < tm->tm_mon; ++i) {
+        days += mdays[i];
+    }
+    if (tm->tm_mon > 1 && is_leap_year(year)) {
+        ++days;
+    }
+    days += tm->tm_mday - 1;
+
+    hours = days * 24 + tm->tm_hour;
+    minutes = hours * 60 + tm->tm_min;
+    seconds = minutes * 60 + tm->tm_sec;
+
+    return seconds;
+}
