@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 1.875d.  */
+/* A Bison parser, made by GNU Bison 2.0.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
    Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
@@ -86,17 +86,18 @@
      T_RRSIG = 312,
      T_NSEC = 313,
      T_DNSKEY = 314,
-     DOLLAR_TTL = 315,
-     DOLLAR_ORIGIN = 316,
-     NL = 317,
-     SP = 318,
-     STR = 319,
-     PREV = 320,
-     BITLAB = 321,
-     T_TTL = 322,
-     T_RRCLASS = 323,
-     URR = 324,
-     T_UTYPE = 325
+     T_SPF = 315,
+     DOLLAR_TTL = 316,
+     DOLLAR_ORIGIN = 317,
+     NL = 318,
+     SP = 319,
+     STR = 320,
+     PREV = 321,
+     BITLAB = 322,
+     T_TTL = 323,
+     T_RRCLASS = 324,
+     URR = 325,
+     T_UTYPE = 326
    };
 #endif
 #define T_A 258
@@ -156,23 +157,24 @@
 #define T_RRSIG 312
 #define T_NSEC 313
 #define T_DNSKEY 314
-#define DOLLAR_TTL 315
-#define DOLLAR_ORIGIN 316
-#define NL 317
-#define SP 318
-#define STR 319
-#define PREV 320
-#define BITLAB 321
-#define T_TTL 322
-#define T_RRCLASS 323
-#define URR 324
-#define T_UTYPE 325
+#define T_SPF 315
+#define DOLLAR_TTL 316
+#define DOLLAR_ORIGIN 317
+#define NL 318
+#define SP 319
+#define STR 320
+#define PREV 321
+#define BITLAB 322
+#define T_TTL 323
+#define T_RRCLASS 324
+#define URR 325
+#define T_UTYPE 326
 
 
 
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 39 "zparser.y"
+#line 42 "zparser.y"
 typedef union YYSTYPE {
 	domain_type	 *domain;
 	const dname_type *dname;
@@ -182,8 +184,8 @@ typedef union YYSTYPE {
 	uint16_t	  type;
 	uint16_t	 *unknown;
 } YYSTYPE;
-/* Line 1285 of yacc.c.  */
-#line 187 "zparser.h"
+/* Line 1318 of yacc.c.  */
+#line 189 "zparser.h"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
